===============================
ROS Bag Python Controller
===============================


.. image:: https://img.shields.io/pypi/v/pyrosbag.svg
        :target: https://pypi.python.org/pypi/pyrosbag

.. image:: https://img.shields.io/travis/masasin/pyrosbag.svg
        :target: https://travis-ci.org/masasin/pyrosbag

.. image:: https://codecov.io/gh/masasin/pyrosbag/branch/master/graph/badge.svg
        :target: https://codecov.io/gh/masasin/pyrosbag

.. image:: https://readthedocs.org/projects/pyrosbag/badge/?version=latest
        :target: https://pyrosbag.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/masasin/pyrosbag/shield.svg
     :target: https://pyup.io/repos/github/masasin/pyrosbag/
     :alt: Updates

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
     :target: https://github.com/masasin/pyrosbag

Programmatically control ROS Bag files with Python. Look at ``rosbag_pandas``
on PyPI for an excellent package which allows you to work with the data
directly.

* Free software: MIT license
* Documentation: https://pyrosbag.readthedocs.io.


Features
--------

* General Bag class
* ``rosbag play``

To do
-----

* check
* compress
* decompress
* filter
* fix
* help
* info
* record
* reindex

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

